@@ -13,7 +13,7 @@ from meutils.datamodels.ArticleInfo import ArticleInfo
 
 
 def get_feats(ac):
-    logger.info(ac)
+    # logger.info(ac)
 
     _ = ac.pop('category')
     articleInfo = ArticleInfo(**ac)
@@ -38,9 +38,12 @@ def predict_strict(**ac):
 def predict_nostrict(**ac):
     X = get_feats(ac)
     text = ac.get("title", "请输入一个文本")
+    pred1 = np.array([[0.9611697, 0.03883027]])[:, 1].tolist()[0]
+    pred2 = np.array([[0.9611697, 0.03883027]])[:, 1].tolist()[0]
 
-    pred = 1
-    _ = {'prob': [1, 1], 'checkSuggestion': 'PASS' if pred > 0.8 else 'REVIEW'}
+    pred = pred1 * 0.8 + pred2 * 0.2
+
+    _ = {'prob': [pred1, pred2], 'checkSuggestion': 'PASS' if pred > 0.8 else 'REVIEW'}
 
     return _
 
